// This file is part of Moodle - http://moodle.org/ //
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Course format selection handler.
 *
 * @module     block_infoscours/addauthor
 * @copyright  UNESS | Pimenko 2024
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @since      4.0
 */

import $ from 'jquery';

const Selectors = {
    actions: {
        addauthorfield: '[data-action="block_infoscours/add_author_button"]',
    },
};

let confirmClicked = false;
export const init = (authorcount) => {
    if (authorcount > 0) {
        for (let i = 1; i <= 3; i++) {
            const element = $(`div[data-groupname="additional${i}_group"]`);
            element.addClass('authorshow').removeClass('d-none');
        }
        // Prevent users to add more field with button.

        if (authorcount === 3) {
            $('[data-action="block_infoscours/add_author_button"]').prop("disabled", true);
        }
    }

    $(document.body).on('click', function(e) {
        if ($(e.target).closest(Selectors.actions.addauthorfield).length) {
            authorcount++;
            if (authorcount <= 3) {
                $('div[data-groupname="additional' + authorcount + '_group"]').removeClass('d-none');
                $('div[data-groupname="additional' + authorcount + '_group"]').addClass('authorshow');

                if (authorcount === 3) {
                    $('[data-action="block_infoscours/add_author_button"]').prop("disabled", true);
                }
            }
        }
        if ($(e.target).is('#confirmAiConsent')) {
            const checkbox = $("input.form-check-input[name='config_check_ai']");
            if (checkbox) {
                // Hide the modal.
                $('#aiConsentModal').modal('hide');
                // Check the checkbox and set confirmClicked to true.
                checkbox.prop('checked', true);
                confirmClicked = true;
            }
        }
    });

    $(document).on('click', '[data-action="block_infoscours/addteam_button"]', function() {
        $('.authorteam').removeClass('d-none');
        $('.authorteam').addClass('authorshow');
        $('[data-action="block_infoscours/addteam_button"]').prop("disabled", true);
    });

    $(document.body).on('change', function(event) {
        const checkbox = $(event.target).closest("input.form-check-input[name='config_check_ai']");
        if (checkbox && checkbox.is(':checked')) {
            $('#aiConsentModal').modal('show');
        }
    });

    $(document).on('hidden.bs.modal', '#aiConsentModal', function() {
        const checkbox = $("input.form-check-input[name='config_check_ai']");
        if (checkbox && !confirmClicked) {
            checkbox.prop('checked', false);
        }
        // Reset confirmClicked for next modal open/close cycle.
        confirmClicked = false;
    });
};