// This file is part of Moodle - http://moodle.org/ //
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Course format selection handler.
 *
 * @module     block_infoscours/addauthor
 * @copyright  UNESS | Pimenko 2024
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 * @since      4.0
 */

export const init = (show, formbutton) => {
    if (show) {
        require(['core/modal_factory', 'core/str'], function(ModalFactory, Str) {
            var titlepromise = Str.get_string('titleerrorrequired', 'block_infoscours');
            var errorpromise = Str.get_string('modalcreationerror', 'block_infoscours'); // Clé pour le message d'erreur

            Promise.all([titlepromise]).then(function(results) {
                var [title] = results;

                return ModalFactory.create({
                    title: title,
                    body: formbutton
                }).then(function(modal) {
                    modal.show();
                });
            }).catch(function(e) {
                // eslint-disable-next-line no-console
                console.error(errorpromise + e);
            });
        });
    }
};