<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Settings for the infoscours block.
 *
 * @package    block_infoscours
 * @copyright  UNESS | Pimenko 2024
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

require_once($CFG->dirroot . '/blocks/infoscours/classes/form/setting/admin_setting_license.php');
require_once($CFG->dirroot . '/blocks/infoscours/classes/form/setting/admin_setting_categories.php');
require_once($CFG->dirroot . '/blocks/infoscours/classes/form/setting/admin_setting_school.php');

if ($ADMIN->fulltree) {
    // Add a section for license configurations.
    $settings->add(
        new admin_setting_heading(
            'block_infoscours_licenseconfig',
            get_string(
                'licenseconfig',
                'block_infoscours',
            ),
            get_string(
                'licenseconfig_desc',
                'block_infoscours',
            ),
        ),
    );

    // Multiline text field for license configuration.
    $settings->add(
        new admin_setting_license(
            'block_infoscours_licenses',
            get_string(
                'licenses',
                'block_infoscours',
            ),
            get_string(
                'licenses_desc',
                'block_infoscours',
            ),
            '',
            PARAM_RAW_TRIMMED,
        ),
    );

    // Add a section for the configurations of categories and associated information.
    $settings->add(
        new admin_setting_heading(
            'block_infoscours_categoryinfo',
            get_string(
                'categoryinfo',
                'block_infoscours',
            ),
            get_string(
                'categoryinfo_desc',
                'block_infoscours',
            ),
        ),
    );

    // Multiline text field for categories and associated information.
    $settings->add(
        new admin_setting_categories(
            'block_infoscours_categories',
            get_string(
                'categories',
                'block_infoscours',
            ),
            get_string(
                'categories_desc',
                'block_infoscours',
            ),
            '',
            PARAM_RAW_TRIMMED,
        ),
    );

    // Add a section for school configurations.
    $settings->add(
        new admin_setting_heading(
            'block_infoscours_schoolinfo',
            get_string(
                'schoolinfo',
                'block_infoscours',
            ),
            get_string(
                'schoolinfo_desc',
                'block_infoscours',
            ),
        ),
    );

    // Multiline text field for school configuration.
    $settings->add(
        new admin_setting_school(
            'block_infoscours_schoollist',
            get_string(
                'schoollist',
                'block_infoscours',
            ),
            get_string(
                'schoollist_desc',
                'block_infoscours',
            ),
            '',
            PARAM_RAW_TRIMMED,
        ),
    );
}
