<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

require_once(__DIR__ . '/../lib.php');

/**
 * Class getmatchinglineitems_testcase
 *
 * This class is used to test the functionality of the getmatchinglineitems function.
 * It extends the advanced_testcase class to inherit its testing capabilities.
 */
class getmatchinglineitems_test extends advanced_testcase {

    /**
     * Test method for the getmatchinglineitems function.
     *
     * This method tests the functionality of the getmatchinglineitems function by passing
     * in a configuration line and a line ID, and verifying that the function returns the
     * expected matching line items.
     *
     * @return void
     */
    public function test_returns_matching_line_items() {

        $configlines = "1|Item1|Item2\n"."2|Item3|Item4";
        $linesids = 2;
        $expectedResult = ['2', 'Item3', 'Item4'];

        $result = getmatchinglineitems($configlines, $linesids);

        $this->assertEquals($expectedResult, $result);
    }

    /**
     * Returns an empty array if no matching items are found.
     *
     * @return void The matching line items or an empty array if no matching items are found.
     */
    public function test_returns_empty_array_if_no_matching_items_found() {

        $configlines = "1|Item1|Item2\n"."2|Item3|Item4";
        $linesids = 3;

        $result = getmatchinglineitems($configlines, $linesids);

        $this->assertEmpty($result);
    }
}
